#!/usr/bin/python
#
# calc_ang_target_moon
# Program to calculate the angular distance between the microlensed target and
#  the Moon
# input: target_RA, Target_dec (hrs,min,sec,deg,min,sec)
# output: angle (decimal degrees)
# Equations from Practical Astronomy with your Calculator by Peter Duffett-Smith
# Written by Y.Tsapras Feb 2009
# Last modification by Y.Tsapras 13 Apr 2011 - added code to catch errors
####################################################################################

# Import required modules
from math import cos, sin, acos, degrees, radians
from hms2dh import hms2dh
from dh2hms import dh2hms
from dms2dd import dms2dd
from dd2dms import dd2dms
from calc_ang import is_number, check_inp
from sys import argv, exit
from os import popen
from string import split as stringsplit

####################################################################################
# Function calc_ang starts here
# Input must be a list containing the RA, Dec of the target object, 6 numbers.
# e.g. calc_and_target_moon([18, 00, 00, -30, 00, 00]) 
# Will calculate the angular distance between an astronomical target and the Moon
def calc_ang_target_moon(coords_2):
    # Check input values
    coords_2  = check_inp(coords_2)
    
    # Get the position of the moon today
    moon = popen("python moon_pos_today.py | grep 'Moon RA'").readlines()
    
    # If the list is empty, exit with warning
    if (moon == []):
    	print "Error: No position for the Moon was returned."
	exit()
    
    s = stringsplit(str(moon[0])," ")
    c1_RA = float(s[2]) # in decimal degrees
    c1_Dec = float( (stringsplit(s[4],'\n'))[0] ) # in decimal degrees
    
    # Convert terget coordinates to decimal form
    c2_RA = hms2dh(coords_2[0], coords_2[1], coords_2[2]) # in hours
    c2_Dec = dms2dd(coords_2[3], coords_2[4], coords_2[5])  # in degrees
    
    # Convert Declination angles from degrees to radians
    cr1_Dec = radians(c1_Dec)
    cr2_Dec = radians(c2_Dec)

    # Print the input coordinates on screen 
    print 'You have given the following coordinates:'
    print 'Moon : RA --> %d %d %.2f' % ( dh2hms(c1_RA) )
    print 'Moon : Dec --> %d %d %.2f' % ( dd2dms(c1_Dec) ) 
    print 'Object : RA --> %d %d %.2f' % (coords_2[0], coords_2[1], coords_2[2])
    print 'Object : Dec --> %d %d %.2f' % (coords_2[3], coords_2[4], coords_2[5]) 
        
    # Calculate RA1 - RA2 and convert to degrees by multiplying by 15
    diff_degrees = (c1_RA - c2_RA) * 15  # in degrees
    diff_radians = radians( diff_degrees ) # in radians

    cos_angle_radians = (sin(cr1_Dec) * sin(cr2_Dec) + \
    			 cos(cr1_Dec) * cos(cr2_Dec) * \
    			 cos(diff_radians)) # All values in radians
    
    angle_radians = acos( cos_angle_radians )
    angle_degrees = degrees( angle_radians )
    angle_dms = dd2dms( angle_degrees )
    
    print 'Sky separation angle = %d degrees %d arcmin %.2f arcsec' % (angle_dms[0],angle_dms[1],angle_dms[2])
    print 'Moon-Target angle = %.3f degrees' % angle_degrees
    
    return angle_dms


###################################################################################
# Commandline run section
# If given 6 space separated numbers from the command line, call calc_ang_targ_moon and return the angular distance.
# The 6 numbers are the RA and Dec for the target  object.
# e.g. python calc_ang.py 18 23 32.11 -30 00 00.0
if __name__ == '__main__':
    if (len(argv) != 7): 
        print "Error: Incorrect number of arguments. Need 6 numbers for RA and Dec the target object."
	print "Example calling sequence: python calc_ang_target_moon.py 18 23 32.11 -30 00 00.0"
	exit()
        
    # Check input and set values
    coords_2  = check_inp([i for i in argv[1:]])
    
    # Set values    
    #coords_2 = [ float(i) for i in argv[1:] ]
    #print coords_2 # uncomment for debugging
    calc_ang_target_moon(coords_2)
    
