#!/usr/bin/python
#
# caldat 
# Program to convert a given Julian date to a calendar date
# input: JD
# output: day,month,year (also accepts decimals)
#
# Equations from Practical Astronomy with your Calculator by Peter Duffett-Smith
#
# Written by Y.Tsapras Feb 2009
# Last modification by Y.Tsapras 14 Apr 2011 - added code to catch errors
####################################################################################

# Import required modules
from sys import argv, exit


####################################################################################
# Function caldat
# Converts a given JD to calendar day, month, year
def caldat( jd ):
    # Catch exception if input is not a number
    try:
        float(jd)
    except ValueError:
        print "Input must be a number corresponding to a valid Julian Date."
	exit()
    
    jd = jd + 0.5
    I = int(jd)
    F = jd - I

    if (I > 2299160):
        A = int( (I - 1867216.25) / 36524.25 )
        B = I + 1 + A - int(A / 4)
    else:
        B = I
 
    C = B + 1524
    D = int( (C - 122.1) / 365.25 )
    E = int(365.25 * D)
    G = int( (C - E) / 30.6001 )

    dd = C - E + F - int(30.6001 * G)
    if (G < 13.5):
        mm = G - 1
    if (G > 13.5):
        mm = G - 13

    if (mm > 2.5):
        yyyy = D - 4716
    if (mm < 2.5):
        yyyy = D - 4715

    # print 'Day, month, year:', dd, mm, yyyy
    return dd, mm, yyyy


####################################################################################
# Commandline run section
if __name__ == '__main__':
    if ( len(argv) != 2 ): 
        print "Error: Incorrect number of arguments. Only the julian date is required."
	print "Example calling sequence: python caldat.py 2455665.5"
	exit()
    
    try:
        caldat( float(argv[1]) )
	dd, mm, yyyy = caldat( float(argv[1]) )
	print 'Day, month, year:', dd, mm, yyyy
    except ValueError:
        print "Input must be a number corresponding to a valid Julian Date."
	exit()
