#!/usr/bin/python
#
# dd2dms 
# Program to convert decimal degrees to degrees, arcminutes and arcseconds
# input: ddeg (decimal degrees)
# output: deg,arcmin,arcsec.ss
#
# Equations from Practical Astronomy with your Calculator by Peter Duffett-Smith
#
# Written by Y.Tsapras Feb 2009
#
# Modification history:
# - Y. Tsapras 14 Apr 2011
# - Y. Tsapras 18 May 2011 - fixed a bug when ddeg was -0.xxx 
#                            and the negative sign wasn't picked up
####################################################################################

# Import required modules
from sys import argv, exit


####################################################################################
# Function dd2dms
# Converts a given angle in decimal degrees to degrees, arcminutes and arcseconds
def dd2dms(ddeg):
    # Catch exception if input is not a number
    try:
        float(ddeg)
    except ValueError:
        print "Input must be a number corresponding to a valid angle in decimal degrees."
	exit()
    
    if (ddeg >= 0):
        dd = int(ddeg)
        A = (ddeg - dd) * 60
        mm = int(A)
        ss = (A - mm) * 60
        # print '%d deg, %d arcmin %.2f arcsec' % (dd,mm,ss)
        return dd, mm, ss
    else:
        dd = int(abs(ddeg))
        A = (abs(ddeg) - abs(dd)) * 60
        mm = int(A)
        ss = (A - mm) * 60
        # print '%d deg, %d arcmin %.2f arcsec' % (-dd,-mm,-ss)
        return -dd, -mm, -ss


####################################################################################
# Commandline run section
if __name__ == '__main__':
    if ( len(argv) != 2 ): 
        print "Error: Incorrect number of arguments. Input must be a number (decimal degrees)."
	print "Example calling sequence: python dd2dms.py 35.0"
	exit()
    
    try:
        dd2dms( float(argv[1]) )
	dd, mm, ss = dd2dms( float(argv[1]) )
	print '%d deg, %d arcmin %.2f arcsec' % (dd,mm,ss)
    except ValueError:
        print "Input must be a number corresponding to a valid angle in decimal degrees."
	exit()
