#!/usr/bin/python
#
# dms2dd 
# Program to convert degrees, arcminutes and arcseconds to decimal degrees
# input: deg,arcmin,arcsec.ss
# output: ddeg decimal degrees
#
# Equations from Practical Astronomy with your Calculator by Peter Duffett-Smith
#
# Written by Y.Tsapras Feb 2009
# Modification history: 
# YT 18 May 2010 - added check
# YT 6 Apr 2011 - fixed a bug with the signs
# YT 18 Apr 2011 - added error catches and command-line call
# Y. Tsapras 18 May 2011 - fixed a bug when degr was -0, it was 
#                          picking the coordinates up as +ve
####################################################################################

# Import required modules
from sys import argv, exit

# Sanity check procedure to ensure valid input
def do_check(degr, mm, ss):
    for val in [degr, mm, ss]:
 	if (type(val).__name__=='int' or  type(val).__name__=='float'):
 	    check_id = '0'
 	    continue
 	else:
 	    check_id = '1'
	    print "Data type is invalid. %s is not an integer or floating point number." % str(val)
	    exit()
    #return check_id


# Begin dms2dd
def dms2dd(degr, mm, ss):
    # run the sanity check
    do_check(degr,mm,ss)
    
    if (degr >= 0 and mm >= 0 and ss >= 0):
        ddeg = degr + abs(mm)/60.0 + abs(ss)/3600.0
        #print 'In decimal degrees: %.3f' % ddeg
        return ddeg
    else:
        ddeg = -(abs(degr) + abs(mm)/60.0 + abs(ss)/3600.0) 
        #print 'In decimal degrees: %.3f' % ddeg
        return ddeg


####################################################################################
# Commandline run section
if __name__ == '__main__':
    if ( len(argv) != 4 ): 
        print "Error: Incorrect number of arguments. Input must be three numbers separated by spaces (deg, arcmin, arcsec)."
	print "Example calling sequence: python dms2dd.py 12 10 43.2"
	exit()
    
    try:
        dms2dd( float(argv[1]), float(argv[2]), float(argv[3]) )
	ddeg = dms2dd( float(argv[1]), float(argv[2]), float(argv[3]) )
	print 'In decimal degrees: %.3f' % ddeg
    except ValueError:
        print "Error: Input must be three numbers separated by spaces (deg, arcmin, arcsec)."
	exit()
