#!/usr/bin/python
#
# gst2lst
# Program to convert Greenwich mean sidereal time to local sidereal time
# input: GST (in hr, min, sec), longitude, direction (0 = W, 1 = E)
# output: LST (in hr, min, sec) 
# 
# Equations from Practical Astronomy with your Calculator by Peter Duffett-Smith
#
# Written by Y.Tsapras Feb 2009
#
# Modification history
#  YT - 19 Apr 2011 - Added catches for input errors. 
#  YT - 19 Apr 2011 - Added command line call.
####################################################################################

# Import required modules
from hms2dh import hms2dh
from dh2hms import dh2hms
from sys import exit, argv

####################################################################################
# Check if a string is a number
def is_number(s):
    try:
        float(s)
        return True
    except ValueError:
        return False


####################################################################################
# Function gst2lst starts here
# converts Greenwich Mean Sidereal Time to Local Sidereal Time
def gst2lst(hrs, mins, sec, longitude, direction):
    # Catch exception if input is not a number
    try:
        float(hrs)
	if ( float(hrs) < 0 or float(hrs) > 24):
	    print "Error: gst2lst : First input element must be a valid hour number between 0 and 24."
	    exit()
    except ValueError:
        print "Error: gst2lst : First input element must be a valid hour number between 0 and 24."
	exit()
    # Check that the mins, sec input values are sensible
    for i in (mins, sec):
        if ( is_number(i) == False ):
	    print "Error: gst2lst : %s is not a valid number." % str(i)
	    exit()
	else:
	    if ( i < 0 or i  > 60 ):
	        print "Error: gst2lst : Input minutes and seconds must have values between 0 and 60."
	        exit()
    # Check that the longitude is a valid input
    if ( is_number(longitude) == False ):
        print "Error: gst2lst : Longitude must be a number."
	exit()
    # Check that the input direction is either 0, 1, "W" or "E"
    if ( direction not in [0, 1, "W", "E", "0", "1"] ):
        print 'Error: gst2lst : Invalid input for direction: valid options are 0, 1, "W", "E" '
	exit()
    else:
        if ( direction == "W" ): direction = 0
	if ( direction == "E" ): direction = 1
        if ( direction == "0" ): direction = 0
	if ( direction == "1" ): direction = 1
    
    # Convert to decimal hours
    GST = hms2dh(hrs, mins, sec)
    long_diff = float(longitude)/15 
    if (direction == 1):
        nGST = GST + long_diff
    elif (direction == 0):
        nGST = GST - long_diff
    else:
        print 'Error: gst2lst : direction argument must be 0(=W), 1(=E), "W" or "E".' 
        exit()
    
    # This is the LST in decimal hours
    if (nGST > 24):
        LST = nGST - 24
    elif (nGST < 0):
        LST = nGST + 24
    else:
        LST = nGST
    
    # Convert result to hrs min sec
    LST = dh2hms(LST)
    print 'Local sidereal time:', LST
    return LST


####################################################################################
# Commandline run section
if __name__ == '__main__':
    if ( len(argv) != 6 ): 
        print "Error: Incorrect number of arguments. Input must have 5 elements: hrs, mins, sec, longitude, direction"
	print 'Example calling sequence: python gst2lst.py 4 40 5.23 64 "W" '
	exit()
    
    try:
        gst2lst( float(argv[1]),  float(argv[2]), float(argv[3]), float(argv[4]), str(argv[5]) )
	# print 'Local sidereal time:', LST
    except ValueError:
        print "Error: Incorrect number of arguments. Input must have 5 elements: hrs, mins, sec, longitude, direction"
	print "Example calling sequence: python gst2lst.py 4 40 5.23 64 W"
	exit()
