#!/usr/bin/python
#
# hms2dh 
# Program to convert hours, minutes and seconds to decimal hours
# input: hh,mm,ss.ss
# output: dhours (decimal hours)
#
# Equations from Practical Astronomy with your Calculator by Peter Duffett-Smith
#
# Written by Y.Tsapras Feb 2009
# Modification history
# Y. Tsapras 6 May 2011 - added catch for errors and command line call
####################################################################################


# Import required modules
from sys import argv, exit


####################################################################################
# Sanity check procedure to ensure valid input
def do_check( hh, mm, ss ):
    for val in [ hh, mm, ss ]:
 	if (type(val).__name__=='int' or  type(val).__name__=='float'):
 	    check_id = '0'
 	    continue
 	else:
 	    check_id = '1'
	    print "Data type is invalid. %s is not an integer or floating point number." % str(val)
	    exit()
    return check_id

# begin hms2dh
def hms2dh( hh, mm, ss ):
    # run sanity check
    try:
        do_check( float(hh), float(mm), float(ss) )
    except ValueError:
        print "Error: hms2dh requires 3 numbers: hh, mm, sec. Accepts 24hr clock."
	exit()
    dhours = hh + abs(mm)/60.0 + abs(ss)/3600.0
    #print 'In decimal hours: %.3f' % dhours
    return dhours


####################################################################################
# Allow calls from the prompt
# e.g python hms2dh.py 18 31 27.0
if __name__ == "__main__":
    if ( len(argv) != 4 ):
        print "Error: Incorrect number of arguments. hms2dh.py requires 3 numbers: hh, mm, sec. Accepts 24hr clock."
	print "e.g. python hms2dh.py 18 31 27.0"
	exit() 
    # run sanity check
    try:
        do_check( float(argv[1]), float(argv[2]), float(argv[3]) )
    except ValueError:
        print "Error: hms2dh.py requires 3 numbers: hh, mm, sec. Accepts 24hr clock."
	print "e.g. python hms2dh.py 18 31 27.0"
	exit() 
    hh, mm, ss = float(argv[1]), float(argv[2]), float(argv[3])
    hms2dh(hh, mm, ss)
