#!/usr/bin/python
#
# lst2gst
# Program to convert Local sidereal time to Greenwich mean sidereal time
# input: LST (in hr, min, sec), longitude, direction (0 = W, 1 = E)
# output: GST (in hr, min, sec) 
#
# Equations from Practical Astronomy with your Calculator by Peter Duffett-Smith
#
# Written by Y.Tsapras Feb 2009
#
# Modification history
# Y. Tsapras 6 May 2011 - added catch for errors and command line call
####################################################################################

# Import required libraries
from hms2dh import hms2dh
from dh2hms import dh2hms
from sys import argv, exit


####################################################################################
# Check if a string is a number
def is_number(s):
    try:
        float(s)
        return True
    except ValueError:
        return False


####################################################################################
# Function lst2gst starts here
# converts Local sidereal time to Greenwich mean sidereal time
def lst2gst(hrs, mins, sec, longitude, direction):
    # Catch exception if input is not a number
    try:
        float(hrs)
	if ( float(hrs) < 0 or float(hrs) > 24):
	    print "Error: First input element must be a valid hour number between 0 and 24."
	    exit()
    except ValueError:
        print "Error: First input element must be a valid hour number between 0 and 24."
	exit()
    # Check that the mins, sec input values are sensible
    for i in (mins, sec):
        if ( is_number(i) == False ):
	    print "Error: %s is not a valid number." % str(i)
	    exit()
	else:
	    if ( i < 0 or i  > 60 ):
	        print "Error: Input minutes and seconds must have values between 0 and 60."
	        exit()
    # Check that the longitude is a valid input
    if ( is_number(longitude) == False ):
        print "Error: Longitude must be a number."
	exit()
    # Check that the input direction is either 0, 1, "W" or "E"
    if ( direction not in [0, 1, "W", "E", "0", "1"] ):
        print 'Error: Invalid input for direction: valid options are 0, 1, "W", "E" '
	exit()
    else:
        if ( direction == "W" ): direction = 0
	if ( direction == "E" ): direction = 1
        if ( direction == "0" ): direction = 0
	if ( direction == "1" ): direction = 1
    
    # Convert to decimal hours
    LST = hms2dh(hrs, mins, sec)
    long_diff = float(longitude) / 15.0
    # If the dicection is East, subtract, otherwise (West),add.
    if (direction == 1):
        nLST = LST - long_diff
    elif (direction == 0):
        nLST = LST + long_diff
    else:
        print '!!!Error!!! direction argument must be 0(=W) or 1(=E).' 
        exit()

    # This is the GST in decimal hours
    if (nLST >= 24):
        GST = nLST - 24
    elif (nLST < 0):
        GST = nLST + 24
    else:
        GST = nLST

    # Convert result to hrs min sec
    GST = dh2hms(GST)
    print 'Greenwich mean sidereal time: %d %d %.2f' % (GST[0],GST[1],GST[2])
    return GST


####################################################################################
# Allow calls from the prompt
# e.g python lst2gst 0 24 5.23 64 "W"
if __name__ == "__main__":
    if ( len(argv) != 6 ):
        print "Error: Incorrect number of arguments. lst2gst.py requires 5 arguments: hrs, mins, sec, longitude, direction"
	print 'e.g. python lst2gst.py 0 24 5.23 64 "W"'
	exit() 
    # run sanity check
    try:
        lst2gst( float(argv[1]),  float(argv[2]), float(argv[3]), float(argv[4]), str(argv[5]) )
    except ValueError:
        print "Error: Incorrect number of arguments. Input must have 5 elements: hrs, mins, sec, longitude, direction"
	print 'e.g. python lst2gst.py 0 24 5.23 64 "W"'
	exit() 
