#!/usr/bin/python
#
# moon_phase
# Program to calculate the moon phase for a given date
# input: Julian date (J2000.0)
# output: moon_phase 
#
# Equations from Practical Astronomy with your Calculator by Peter Duffett-Smith
#
# Written by Y.Tsapras Feb 2009
#
# Modification history
# Y. Tsapras 6 May 2011 - added catch for errors and command line call
####################################################################################

# Import required libraries
from math import cos, sin, atan, atan2, degrees, radians, acos
from moon_pos import moon_pos
from sun_pos import sun_pos
from hms2dh import hms2dh
from sys import argv, exit

####################################################################################
# Function moon_phase starts here
# calculates the moon phase for a given date
def moon_phase( JD ):
    [RAsun, Decsun] = sun_pos( JD )
    [RAmoon, Decmoon, moondist] = moon_pos( JD )
    sundist = 1.49598e8  # Earth-Sun distance (1 AU)
    # convert to radians
    RAmoon = radians( RAmoon * 15.0 )
    Decmoon = radians( Decmoon )
    RAsun = radians( RAsun * 15.0 )		
    Decsun = radians( Decsun )

    # phi = geocentric elongation of the Moon from the Sun    
    phi = ( acos( sin(Decsun) * sin(Decmoon) + cos(Decsun) * \
           cos(Decmoon) * cos(RAsun - RAmoon) ) ) # in radians
    # inc = selenocentric elongation of the Earth from the Sun
    inc = atan2( ( sundist * sin(phi) ), ( moondist - sundist * cos(phi) ) ) # in radians

    illum_fraction = ( 1 + cos(inc) ) / 2.
    # debug:    print 'ras,decs,ram,decm,phi,inc,illum',RAsun,Decsun,RAmoon,Decmoon,phi,inc,illum_fraction

    print 'Moon illumination fraction %.2f' % illum_fraction
    return illum_fraction


####################################################################################
# Allow calls from the prompt
# e.g python moon_phase.py 2455694.2264
if __name__ == "__main__":
    if ( len(argv) != 2 ):
        print "Error: Incorrect number of arguments. moon_phase.py requires 1 argument: julian day (J2000.0)"
	print 'e.g. python moon_phase.py 2455694.2264'
	exit() 
    # run sanity check
    try:
        moon_phase( float(argv[1]) )
    except ValueError:
        print "Error: Incorrect number of arguments. moon_phase.py requires 1 argument: julian day (J2000.0)"
	print 'e.g. python moon_phase.py 2455694.2264'
	exit() 
