#!/usr/bin/python
#
# moon_phase_now
# Program to return the current moon phase - to be run from prompt e.g. python moon_phase_now.py
# input: -
# output: moon_phase 
#
# Equations from Practical Astronomy with your Calculator by Peter Duffett-Smith
#
# Written by Y.Tsapras Feb 2009
#
# Modification history
# Y. Tsapras 11 May 2011 - simplified call
# Y. Tsapras 16 May 2011 - improved accuracy
####################################################################################

# Import required libraries
from math import cos, sin, atan, atan2, degrees, acos, radians
from julday import get_julian
from moon_pos import moon_pos
from sun_pos import sun_pos
from hms2dh import hms2dh
from sys import argv, exit
from time import strftime


####################################################################################
# Function moon_phase starts here

# Extract the current time information
dd = float(strftime("%d"))
mm = float(strftime("%m"))
yyyy = float(strftime("%Y"))
hr_now = float(strftime("%H"))
min_now = float(strftime("%M"))
sec_now = float(strftime("%S"))

JD = get_julian([dd, mm, yyyy, hr_now, min_now, sec_now])
[RAsun, Decsun] = sun_pos( JD )
[RAmoon, Decmoon, moondist] = moon_pos( JD )
sundist = 1.49598e8  # Earth-Sun distance (1 AU)
RAmoon = radians(RAmoon * 15.0)
Decmoon = radians(Decmoon)
RAsun = radians(RAsun * 15.0)    
Decsun = radians(Decsun)

# phi = geocentric elongation of the Moon from the Sun    
phi = ( acos( sin(Decsun) * sin(Decmoon) + cos(Decsun) * \
       cos(Decmoon) * cos(RAsun - RAmoon) ) ) # in radians

# inc = selenocentric elongation of the Earth from the Sun
inc = atan2( (sundist * sin(phi) ), ( moondist - sundist * cos(phi) ) ) # in radians

illum_fraction = ( 1 + cos(inc) ) / 2.
# debug:    print 'ras,decs,ram,decm,phi,inc,illum',RAsun,Decsun,RAmoon,Decmoon,phi,inc,illum_fraction

print 'Moon illumination fraction %.2f' % illum_fraction
