#!/usr/bin/python
#
# ecl2equa
# Program to convert ecliptic to equatorial coordinates
# input: ecliptic longitude, ecliptic latitude (in dms), obliquity
# output: RA, Dec in decimal hours, degrees
# "obliquity" is the obliquity of the ecliptic, the angle between the planes of
#  equator and the ecliptic (in decimal degrees). 
# Equations from Practical Astronomy with your Calculator by Peter Duffett-Smith
# Written by Y.Tsapras Feb 2009
# Modified by Y.Tsapras 21 May 2010

# Import required libraries
from math import cos, sin, tan, asin, acos, atan
from math import degrees as deg
from math import radians as rad
from dms2dd import dms2dd
from dd2dms import dd2dms
from dh2hms import dh2hms

########################################################################################
# Function ecl2equa starts here
def ecl2equa(deg_long, min_long, sec_long, deg_lat, min_lat, sec_lat, obliquity):
    ec_longitude = dms2dd(deg_long,min_long,sec_long) # in decimal degrees
    ec_latitude = dms2dd(deg_lat,min_lat,sec_lat) # in decimal degrees
    
    # Find sine_delta
    sine_delta = (sin(rad(ec_latitude)) * cos(rad(obliquity)) + \
                  cos(rad(ec_latitude)) * sin(rad(obliquity)) * \
		  sin(rad(ec_longitude)))
    delta = asin(sine_delta) # in radians
    delta_deg = deg(delta) # in decimal degrees
    
    y = (sin(rad(ec_longitude)) * cos(rad(obliquity)) - \
         tan(rad(ec_latitude)) * sin(rad(obliquity)))
    
    x = cos(rad(ec_longitude))
    
    alpha = deg(atan(y / x)) # in degrees
    
    # Removing the ambiguity which arises from taking the inverse tan.
    # The rule is that alpha should lie in the appropriate quadrant:
    # if x > 0 and y > 0 then alpha is between 0->90 degrees
    # if x < 0 and y > 0 then alpha is between 90->180 degrees
    # if x < 0 and y < 0 then alpha is between 180->270 degrees
    # if x > 0 and y < 0 then alpha is between 270->360 degrees
    # Add or subtract 180 or 360 to bring it in the correct range.
    
    if x > 0 and y > 0:
        if alpha > 180 and alpha < 270:
	    alpha = alpha - 180
	elif alpha < -90 and alpha > -180:
	    alpha = alpha + 180
	else:
	    print 'alpha in correct range'
    elif x < 0 and y > 0:
        if alpha > 270 and alpha < 360:
            alpha = alpha - 180
	elif alpha > -90 and alpha < 0:
            alpha = alpha +180
	else:
            print 'alpha in correct range'
    elif x < 0 and y < 0:
        if alpha > 0 and alpha < 90:
            alpha = alpha + 180
	else:
            print 'alpha in correct range'
    elif x > 0 and y < 0:
        if alpha > 90 and alpha > 180:
            alpha = alpha + 180
	elif alpha < -180 or alpha > -270:
            alpha = alpha + 360 + 180
	else:
            print 'alpha in correct range'
    else:
        print 'Unknown range'
    
# Convert alpha to hours       
    alpha_hours = alpha / 15.0
    
# Convert from decimals    
    alpha_hms = dh2hms(alpha_hours) # in hms
    delta_dms = dd2dms(delta_deg) # in dms
    
    #print 'RA: %.3f, Dec: %.3f' % (alpha_hours, delta_deg)
    return alpha_hours, delta_deg
    
