#!/usr/bin/python
#
# gst2ut
# Program to convert Greenwich mean sidereal time to universal time
# This calculates the value for the beginning of the day (UT 0h) 
# input: GST (in hr, min, sec)
# output: hrs,min,sec,dd,mm,yyyy 
# Equations from Practical Astronomy with your Calculator by Peter Duffett-Smith
# Written by Y.Tsapras Feb 2009

from julday import julday
from hms2dh import hms2dh
from dh2hms import dh2hms

####################################################################################
# Function gst2ut starts here
def gst2ut(hrs, mins, sec, dd, mm, yyyy):
    jd = julday(dd,mm,yyyy)
    S = jd - 2451545.0
    T = S / 36525.0
    T0 = 6.697374558 + (2400.051336 * T) + (0.000025862 * T * T)

# Reduce the result to the range 0-24 by adding or subtracting multiples of 24
    checking = True
    while checking:
        if (T0 < 0):
            T0 = T0 + 24
        elif (T0 > 24):
            T0 = T0 - 24
        else:
            checking = False #This causes the while loop to stop

# Convert GST to decimal hours
    gstdh = hms2dh(hrs,mins,sec)
    T0 = gstdh - T0

# Reduce the result to the range 0-24 by adding or subtracting multiples of 24
# The result is the GST
    checking = True
    while checking:
        if (T0 < 0):
            T0 = T0 + 24
        elif (T0 > 24):
            T0 = T0 - 24
        else:
            checking = False #This causes the while loop to stop
    UT = T0 * 0.9972695663

# Convert the result to hrs, min, sec
    UT = dh2hms(UT)
    print 'Universal time: %d:%d:%.2f' % (UT[0],UT[1],UT[2])
    return UT
