#!/usr/local/bin/python
#
# nutation
# Calculates the nutation
# The nutation is a periodic oscillation of the rotational axis of the Earth
#  around it's 'mean' position.
# Input : date (JD)
# Output: nutation in longitude, nutation in obliquity (in arcsec)
# Equations based on Astronomical Algorithms by Jean Meeus
# Approximations accurate to 0.5 arcsec in delta_psi and
#  0.1 arcsec in delta_epsilon
# Written by Y.Tsapras Feb 2009
# Last updated by Y.Tsapras Apr 2010

# Import required libraries
from math import cos, sin, acos
from math import degrees as deg
from math import radians as rad
from rd_tables import rd_tables
from julday import julday
from dms2dd import dms2dd
from obliq_eclip import obliq_eclip
from ecl2equa import ecl2equa
from dd2dms import dd2dms
from dh2hms import dh2hms

###############################################################################
# Function nutation starts here
def nutation(JD):
    T = (JD - 2451545.0) / 36525.0
    T2 = T * T
    T3 = T2 * T
    T4 = T3 * T
    
# Longitude of the ascending node of the Moon's mean orbit on
#  the ecliptic measured from the mean equinox of the date
    omega = (125.04452 - 1934.136261 * T)
    
# L = mean longitude of Sun
    L = 280.4665 + 36000.7698 * T # in degrees
    
# L1 = mean longitude of Moon
    L1 = 218.3165 + 481267.8813 * T # in degrees
    
# Nutation in longitude
    delta_psi = (-17.20 * sin(rad(omega)) - 1.32 * sin (rad(2 * L)) - \
                 0.23 * sin(rad(2 * L1)) + 0.21 * sin(rad(2 * omega)))
                    # in arcsec
# Nutation in obliquity
    delta_epsilon = (9.20 * cos(rad(omega)) + 0.57 * cos(rad(2 * L)) + \
                     0.10 * cos(rad(2 * L1)) - 0.09 * cos(rad(2 * omega)))
		    # in arcsec
    return delta_psi, delta_epsilon
